<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Διακομιστής Μεσολάβησης Εφαρμογής</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Τύπος Διακομιστή</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Διεύθυνση IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Θύρα</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Όνομα χρήστη</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Προαιρετικό</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Κωδικός πρόσβασης</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Ελέγξτε το &quot;Χρήση Διακομιστή Μεσολάβησης&quot; στο πλαίσιο του μενού εφαρμογών στον Εκκινητή μετά την ρύθμιση</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Μη έγκυρη διεύθυνση IP</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Μη έγκυρη θύρα</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Αποσύνδεση</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Αποσύνδεση</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Είστε σίγουροι ότι θέλετε να διαγράψετε αυτές τις ρυθμίσεις παραμέτρων;</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Ενσύρματη Σύνδεση: %1 </translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Ασύρματη Σύνδεση %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE Σύνδεση %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Νέο VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Τύπος VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Εξαγωγή</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Δίκτυο</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Διακομιστής Μεσολάβησης Εφαρμογής</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Προσωπικό Hotspot</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Λεπτομέριες Δικτύου</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Σύστημα μεσολάβησης</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Ενσύρματο Δίκτυο</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Ασύρματο Δίκτυο</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Υποδοχέας Δικτύου Ενσύρματης Σύνδεσης</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Προσθήκη Σύνδεσης Δικτύου</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Υποδοχέας Δικτύου Ασύρματης Σύνδεσης</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Σύνδεση σε κρυφό δίκτυο</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Δημιουργία Σύνδεσης PPPoE</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Κατάσταση VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Δημιουργία VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Εισαγωγή VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Τύπος διακομιστή</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL ρύθμισης παραμέτρων</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Διεύθυνση IP</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Θύρα</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Όνομα χρήστη</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Κωδικός πρόσβασης</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Δημιουργία Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Διεπαφή</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Mπάντα</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Πρωτεύον DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Μάσκα Δικτύου</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Πρόθεμα</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Ταχύτητα</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Μη έγκυρη διεύθυνση DNS</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Μη Δεσμευμένο</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Διεύθυνση MAC συσκευής</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Κλωνοποιημένη διεύθυνση MAC </translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Προσαρμογή MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Γενικά</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Γενικά</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Το όνομα υπάρχει ήδη</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Αυτόματη σύνδεση</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Προσθήκη Ρυθμίσεων</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Δημιουργία Hotspot</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>Διεύθυνση IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Μη έγκυρη διεύθυνση IP</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Μη έγκυρη μάσκα δικτύου (netmask)</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Μη έγκυρη πύλη δικτύου (gateway)</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Μάσκα Δικτύου</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Μη έγκυρη διεύθυνση IP</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Μη έγκυρη πύλη δικτύου (gateway)</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Πρόθεμα</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Αυτόματο</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Μη αυτόματα</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Παράβλεψη</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Διεύθυνση IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Αφορά μόνο σχετικούς πόρους</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Μέθοδος</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Μάσκα Δικτύου</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Πρόθεμα</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Μη έγκυρη διεύθυνση IP</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Μη έγκυρη μάσκα δικτύου (netmask)</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Μη έγκυρη πύλη δικτύου (gateway)</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Δίκτυο</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Αντιτίθεση IP </translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Μέθοδος</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Αυτόματο</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Μη αυτόματα</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Παράβλεψη</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Λεπτομέριες Δικτύου</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Σύστημα μεσολάβησης</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Διακομιστής Μεσολάβησης Εφαρμογής</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Λεπτομέριες Δικτύου</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Δίκτυο</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Αντιτίθεση IP </translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Απενεργοποιημένο</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Μη αυτόματα</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Αυτόματο</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Ρύθμιση με τον Διαχειριστή Δικτύου</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Προσωπικό Hotspot</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Όνομα χρήστη</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Υπηρεσία</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Κωδικός πρόσβασης</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Άρνηση ελέγχου ταυτότητας EAP </translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Απόρριψη ελέγχου ταυτότητας PAP </translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Άρνηση ελέγχου ταυτότητας CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Άρνηση ελέγχου ταυτότητας MSCHAP </translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Άρνηση ελέγχου ταυτότητας MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Χωρίς Συμπίεση Δεδομένων BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Χωρίς Ξεφούσκωμα Συμπίεσης Δεδομένων</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Χωρίς Συμπίεση Κεφαλίδας TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Χωρίς Συμπίεση Πεδίου Πρωτοκόλλου</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Καμία συμπίεση Διεύθυνσης/Ελέγχου</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Αποστολή Πακέτων Αντήχησης PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Χρήση MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE με επίβλεψη κατάστασης</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Δημιουργία Σύνδεσης PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Σύστημα μεσολάβησης</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Τύπος διακομιστή</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Μη αυτόματα</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Αυτόματο</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Προαιρετικό</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Θύρα</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Διακομιστής Μεσολάβησης</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS Διακομιστής Μεσολάβησης</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP Διακομιστής Μεσολάβησης</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS Proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Αγνοήστε τις παραπάνω ρυθμίσεις proxy για hosts και domains</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL ρύθμισης παραμέτρων</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Ασφάλεια</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP </translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>ΓΡΗΓΟΡΑ</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Προστατευόμενη EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Αποθήκευση κωδικού για αυτόν τον χρήστη</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Αποθήκευση κωδικού για όλους τους χρήστες</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Πάντα να γίνεται ερώτηση</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Απενεργοποιημένο</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Ανώνυμο</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Πιστοποιήθηκε</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Και τα δύο</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Αυτόματο</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Έκδοση 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Έκδοση 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP Auth</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Ταυτότητα</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Eπιλογές Pwd</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Ιδιωτικό Κλειδί</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Πιστοποιητικό Χρήστη</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Ανώνυμο αναγνωριστικό</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Προμήθεια</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Αρχείο PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Εσωτερικός έλεγχος ταυτότητας</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Έκδοση PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Ιδιωτικός Κωδ. Προσβ.</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Κωδικός πρόσβασης</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Μη έγκυρος κωδικός πρόσβασης</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Προσωπικό</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Ασφάλεια</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Κλειδί</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Κωδικός πρόσβασης</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Απαιτείται ασφάλεια</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Μη έγκυρος κωδικός πρόσβασης</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Προσωπικό</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Κοινόχρηστο κλειδί</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Άνοιγμα συστήματος</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Ασφάλεια</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Πιστοποίηση</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Κλειδί</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Κωδικός πρόσβασης</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Προχωρημένο VPN</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Προσαρμοσμένη Θύρα Πύλης</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Θύρα Πύλης</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Προσαρμόστε το Διάστημα Επαναδιαπραγμάτευσης</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Διάστημα επαναδιαπραγμάτευσης</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Χρήση Συμπίεσης Δεδομένων LZO </translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Χρήση Σύνδεσης TCP </translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Χρήση Συσκευής TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Προσαρμογή Tunnel MTU </translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Προσαρμογή Μεγέθους Τμήματος UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Μέγεθος τμήματος UDP </translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Περιορισμός διοχέτευσης TCP MSS </translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Τυχαίος απομακρυσμένος κεντρικός υπολογιστής</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Προχωρημένο VPN</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (προεπιλογή)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Ασφαλές (προεπιλογή)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Αδύναμο</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T Όταν Είναι Διαθέσιμο (προεπιλογή)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>Πάντα NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Απενεργοποιημένο</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Ομάδα 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Ομάδα 2 (προεπιλογή)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Ομάδα 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Server (default) </translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Ομάδα 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Τομέας</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Προμηθευτής</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Έκδοση</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Κρυπτογράφηση</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Λειτουργία Διέλευσης NAT</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH Group </translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Άμεση Εμπιστευτικότητα</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Τοπική Πύλη</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Απενεργοποίηση Ανίχνευσης Dead Peer</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Ενεργοποίηση IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Όνομα Ομάδας</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID Ομάδας</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Ήδη κοινόχρηστο κλειδί</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Αλγόριθμοι Phase1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Αλγόριθμοι Phase2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Μη έγκυρη πύλη δικτύου (gateway)</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Διακομιστής Μεσολάβησης</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Να επιτρέπεται ο Ασφαλής Δούρειος Ίππος Επιφάνειας Εργασίας Cisco</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD Script</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Πιστοποιητικό Χρήστη</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Ιδιωτικό Κλειδί</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Χρησιμοποιήστε FSID για Key Passphrase </translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Μη έγκυρη πύλη δικτύου (gateway)</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Πιστοποιητικά (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Κωδικός πρόσβασης</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Πιστοποιητικά με κωδικούς πρόσβασης (TLS) </translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Στατικό κλειδί</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Αποθηκεύτηκε</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Δεν Απαιτείται</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Τύπος Πιστοποίησης</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Πιστοποιητικό Χρήστη</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Ιδιωτικό Κλειδί</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Eπιλογές Pwd</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Ιδιωτικός Κωδ. Προσβ.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Όνομα χρήστη</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Προσαρμογή Κατεύθυνσης Κλειδιού</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Βασική Κατεύθυνση</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Απομακρυσμένη IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Τοπική IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Όλα τα διαθέσιμα (προεπιλογή)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (λιγότερο ασφαλές)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (πιο ασφαλές)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Άρνηση ελέγχου ταυτότητας EAP </translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Απόρριψη ελέγχου ταυτότητας PAP </translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Άρνηση ελέγχου ταυτότητας CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Άρνηση ελέγχου ταυτότητας MSCHAP </translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Άρνηση ελέγχου ταυτότητας MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Χωρίς Συμπίεση Δεδομένων BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Χωρίς Ξεφούσκωμα Συμπίεσης Δεδομένων</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Χωρίς Συμπίεση Κεφαλίδας TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Χωρίς Συμπίεση Πεδίου Πρωτοκόλλου</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Καμία συμπίεση Διεύθυνσης/Ελέγχου</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Αποστολή Πακέτων Αντήχησης PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Χρήση MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Ασφάλεια</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE με επίβλεψη κατάστασης</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Κατάσταση VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Δημιουργία VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Εισαγωγή VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Σφάλμα Εισαγωγής</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Σφάλμα αρχείου</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Δεν Απαιτείται</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Τύπος διακομιστή</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP διακομιστή</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Θύρα</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Συνεχής προσπάθεια σε περίπτωση αποτυχίας</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Όνομα χρήστη</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Κωδικός πρόσβασης</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Αρχείο CA</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Αγνόηση Προειδοποιήσεων Πιστοποίησης</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Χρήση Επεκτάσεων TLS για Hostname </translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Ασφάλεια VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Προεπιλογή</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Κρυπτογράφηση</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth </translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Μη έγκυρη πύλη δικτύου (gateway)</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Αποθηκεύτηκε</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Δεν Απαιτείται</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Όνομα χρήστη</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Eπιλογές Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Κωδικός πρόσβασης</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Τομέας NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP διακομιστή</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Θύρα</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Όνομα χρήστη</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Κωδικός πρόσβασης</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Μη έγκυρη πύλη δικτύου (gateway)</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Ιδιωτικό Κλειδί</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH Agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Έξυπνη Κάρτα</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Ήδη κοινόχρηστο κλειδί</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Τύπος Πιστοποίησης</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Πιστοποιητικό Χρήστη</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Όνομα χρήστη</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Κωδικός πρόσβασης</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Αιτηθείτε μια εσωτερική IP διεύθυνση </translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Επιβολή UDP εγκλεισμού</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Χρήση συμπίεσης IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Ενεργοποίηση Προσαρμόσμένων Προτάσεων Κρυπτογράφησης</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Έλεγχος ταυτότητας VPN TLS </translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Προεπιλογή</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Πελάτης</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Διακομιστής</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Συμφωνία θέματος</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Απομακρυσμένος τύπος πιστοποιητικού</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Αρχείο κλειδιού</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Προσαρμογή Κατεύθυνσης Κλειδιού</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Βασική Κατεύθυνση</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Μη έγκυρη πύλη δικτύου (gateway)</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Αποθηκεύτηκε</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Ερώτηση</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Δεν Απαιτείται</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Όνομα χρήστη</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Eπιλογές Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Κωδικός πρόσβασης</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Όνομα Ομάδας</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Κωδ. Προσβ. Ομάδας</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Χρήση Υβριδικής Πιστοποίησης</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Αρχείο CA</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Συνδέστε το καλώδιο δικτύου πρώτα</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Υποδοχέας Δικτύου Ενσύρματης Σύνδεσης</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Προσθήκη Σύνδεσης Δικτύου</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Επιλογή Ρυθμίσεων</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Υποδοχέας Δικτύου Ασύρματης Σύνδεσης</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Απενεργοποίηση Φορητού Σημείου Πρόσβασης</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Απενεργοποιήστε το φορήτο σημείο πρόσβασης πρώτα, εαν θέλετε να συνδεθείτε σε ένα δίκτυο ασύρματης σύνδεσης</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Σύνδεση σε κρυφό δίκτυο</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Μη Δεσμευμένο</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Απαιτείται</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Διεύθυνση MAC συσκευής</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Προσαρμογή MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Πρωτόκολλο</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Τύπος Ασφαλείας</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kανάλι</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Mπάντα</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Διεπαφή</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Μάσκα Δικτύου</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Πρωτεύον DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Πρόθεμα</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Ταχύτητα</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Συσκευή Αποσυνδέθηκε</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Συνδεδεμένο αλλά χωρίς πρόσβαση στο διαδίκτυο</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Δεν Συνδέθηκε</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Το καλώδιο δικτύου, αποσυνδέθηκε</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Σύνδεση</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Πιστοποίηση</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Απόκτηση Διεύθυνσης IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Συνδέθηκε</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Αποσυνδέθηκε</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Αντιτίθεση IP </translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Αποτυχία</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Απόκτηση Διεύθυνσης</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Ενσύρματο Δίκτυο</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Ενσύρματο Δίκτυο %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Ασύρματο Δίκτυο</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Ασύρματο Δίκτυο %1</translation>
    </message>
</context>
</TS>